@@ -1,7 +1,7 @@
 from .const import VERSION
 from .gql_handler import *
 from datetime import datetime
-from .exeption_classes import LoginError
+from .exception_classes import LoginError
 
 class PyXploraApi:
     def __init__(self, countrycode: str, phoneNumber: str, password: str, userLang: str, timeZone: str, watchNo: int=0) -> None:
@@ -30,7 +30,10 @@ class PyXploraApi:
 
         self.__gqlHandler = None
         self.__issueToken = None
-        self.watch = None
+        # self.watch = None
+
+        self.watchs = []
+
         self.user = None
 
     def __login(self, forceLogin=False) -> dict:
@@ -76,7 +79,8 @@ class PyXploraApi:
         token = self.__login(forceLogin)
         if token:
             if ('user' in token):
-                self.watch = token['user']['children'][self.watch_no]['ward']
+                # self.watch = token['user']['children'][self.watch_no]['ward']
+                self.watchs = token['user']['children']
                 self.user = token['user']
                 return
         raise LoginError("Login to Xplora® API failed. Check your input!")
@@ -142,18 +146,48 @@ class PyXploraApi:
         return datetime.fromtimestamp(self.user['update']).strftime('%Y-%m-%d %H:%M:%S')
 
 ##### Watch Info #####
-    def getWatchUserID(self) -> str:
-        return self.watch['id']
-    def getWatchUserName(self) -> str:
-        return self.watch['name']
-    def getWatchUserIcon(self) -> str:
-        return f"https://api.myxplora.com/file?id={self.watch['file']['id']}"
-    def getWatchXcoin(self) -> int:
-        return self.watch['xcoin']
-    def getWatchCurrentStep(self) -> int:
-        return self.watch['currentStep']
-    def getWatchTotalStep(self) -> int:
-        return self.watch['totalStep']
+    def getWatchUserID(self, childPhoneNumber: int=0) -> str:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['id']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return watch['ward']['id']
+        raise Exception("Child phonenumber not found!")
+    def getWatchUserName(self, childPhoneNumber: int=0) -> str:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['name']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return watch['ward']['name']
+        raise Exception("Child phonenumber not found!")
+    def getWatchUserIcon(self, childPhoneNumber: int=0) -> str:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['ward']['file']['id']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return f"https://api.myxplora.com/file?id={watch['ward']['file']['id']}"
+        raise Exception("Child phonenumber not found!")
+    def getWatchXcoin(self, childPhoneNumber: int=0) -> int:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['xcoin']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return watch['ward']['xcoin']
+        raise Exception("Child phonenumber not found!")
+    def getWatchCurrentStep(self, childPhoneNumber: int=0) -> int:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['currentStep']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return watch['ward']['currentStep']
+        raise Exception("Child phonenumber not found!")
+    def getWatchTotalStep(self, childPhoneNumber: int=0) -> int:
+        if childPhoneNumber == 0:
+            return self.watchs[childPhoneNumber]['ward']['totalStep']
+        for watch in self.watchs:
+            if watch['ward']['phoneNumber'] == str(childPhoneNumber):
+                return watch['ward']['totalStep']
+        raise Exception("Child phonenumber not found!")
 
     def getWatchAlarm(self) -> list:
         retryCounter = 0
